##  Overview
We're introducing enhancements to the [Self-Built Software Discovery REST API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Feu.leanix.net%2Fservices%2Ftechnology-discovery%2Fv1%2Fopenapi%2Fswagger-ui%2Findex.html%23%2FSBOM%2Fleanix-v1-factsheets-sboms-ingest "https://eu.leanix.net/services/technology-discovery/v1/openapi/swagger-ui/index.html#/SBOM/leanix-v1-factsheets-sboms-ingest") to improve SBOM file ingestion and system performance for our customers. These changes will come into effect on April 7, 2025, following a transition period. During this period, you can test and familiarize yourself with the new behavior while continuing to use your current API implementation. However, after the transition period, only the new behavior will be supported.
  * Transition period: March 10, 2025 – April 6, 2025
  * Switchover date: April 7, 2025


To learn more about self-built software discovery and SBOMs, refer to:
  * [Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX Technology Risk and Compliance enables you to automate the discovery of your self-built software by integrating this process into your developer toolchain.")
  * [Software Bill of Materials (SBOM)](https://help.sap.com/docs/leanix/ea/software-bill-of-materials-sbom?locale=en-US&state=PRODUCTION&version=CLOUD "To understand and manage dependencies among your microservices, generate SBOM files and ingest them into SAP LeanIX using our API.")
